==> ovirt-engine-sdk-java-4.1.3.tar.gz: ovirt-engine-sdk-java-4.1.3/target/generated-sources/org/ovirt/engine/sdk4/services/AssignedAffinityLabelsService.java <==
/*
Copyright (c) 2015 Red Hat, Inc.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package org.ovirt.engine.sdk4.services;

import java.io.IOException;
import java.util.List;
import org.ovirt.engine.sdk4.Request;
import org.ovirt.engine.sdk4.Response;
import org.ovirt.engine.sdk4.Service;
import org.ovirt.engine.sdk4.builders.AffinityLabelBuilder;
import org.ovirt.engine.sdk4.types.AffinityLabel;

/**
 * This service is used to list and manipulate affinity labels that are
 * assigned to supported entities when accessed using entities/affinitylabels.
 */
public interface AssignedAffinityLabelsService extends Service {
    /**
     * Attaches a label to an entity.
     */
    public interface AddRequest extends Request<AddRequest, AddResponse> {
        AddRequest label(AffinityLabel label);
        AddRequest label(AffinityLabelBuilder label);
    }
    
    /**
     * Attaches a label to an entity.
     */
    public interface AddResponse extends Response {
        AffinityLabel label();
    }
    
    /**
     * Attaches a label to an entity.
     */
    AddRequest add();
    
    /**
     * Lists all labels that are attached to an entity.
     */
    public interface ListRequest extends Request<ListRequest, ListResponse> {
    }
    
    /**
     * Lists all labels that are attached to an entity.
     */
    public interface ListResponse extends Response {
        List<AffinityLabel> label();
    }
    
    /**
     * Lists all labels that are attached to an entity.
     */
    ListRequest list();
    
    /**
     * Link to the specific entity-label assignment to allow
     * removal.
     */
    AssignedAffinityLabelService labelService(String id);
    /**
     * Service locator method, returns individual service on which the URI is dispatched.
     */
    Service service(String path);
}

==> ovirt-engine-sdk-java-4.1.6.tar.gz: ovirt-engine-sdk-java-4.1.6/target/generated-sources/org/ovirt/engine/sdk4/services/AssignedAffinityLabelsService.java <==
/*
Copyright (c) 2015 Red Hat, Inc.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package org.ovirt.engine.sdk4.services;

import java.io.IOException;
import java.util.List;
import org.ovirt.engine.sdk4.Request;
import org.ovirt.engine.sdk4.Response;
import org.ovirt.engine.sdk4.Service;
import org.ovirt.engine.sdk4.builders.AffinityLabelBuilder;
import org.ovirt.engine.sdk4.types.AffinityLabel;

/**
 * This service is used to list and manipulate affinity labels that are
 * assigned to supported entities when accessed using entities/affinitylabels.
 */
public interface AssignedAffinityLabelsService extends Service {
    /**
     * Attaches a label to an entity.
     */
    public interface AddRequest extends Request<AddRequest, AddResponse> {
        AddRequest label(AffinityLabel label);
        AddRequest label(AffinityLabelBuilder label);
    }
    
    /**
     * Attaches a label to an entity.
     */
    public interface AddResponse extends Response {
        AffinityLabel label();
    }
    
    /**
     * Attaches a label to an entity.
     */
    AddRequest add();
    
    /**
     * Lists all labels that are attached to an entity.
     * 
     * The order of the returned entities isn't guaranteed.
     */
    public interface ListRequest extends Request<ListRequest, ListResponse> {
    }
    
    /**
     * Lists all labels that are attached to an entity.
     * 
     * The order of the returned entities isn't guaranteed.
     */
    public interface ListResponse extends Response {
        List<AffinityLabel> label();
    }
    
    /**
     * Lists all labels that are attached to an entity.
     * 
     * The order of the returned entities isn't guaranteed.
     */
    ListRequest list();
    
    /**
     * Link to the specific entity-label assignment to allow
     * removal.
     */
    AssignedAffinityLabelService labelService(String id);
    /**
     * Service locator method, returns individual service on which the URI is dispatched.
     */
    Service service(String path);
}
